package com.tuoheng.airportGzdp.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tuoheng.airportGzdp.common.JsonResult;
import com.tuoheng.airportGzdp.entity.Tenant;
import com.tuoheng.airportGzdp.mapper.TaskMapper;
import com.tuoheng.airportGzdp.service.ITaskService;
import com.tuoheng.airportGzdp.service.ITenantService;
import com.tuoheng.airportGzdp.vo.TaskListVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 机场任务表 服务实现类
 * </p>
 *
 * @author 拓恒
 * @since 2023-10-26
 */
@Service
@Slf4j
public class TaskServiceImpl extends ServiceImpl<TaskMapper, TaskListVo> implements ITaskService {

    @Autowired
    private TaskMapper taskMapper;
    @Autowired
    private ITenantService tenantService;
    /**
     * 查询机场任务列表
     * @return
     */
    @Override
    public JsonResult getList(String tenantCode,int limit) {
        Tenant tenant = tenantService.selectByTenantCode(tenantCode);
        //已完成的任务
        List listRun =  taskMapper.getRunList(tenant.getId(),limit);
        if (listRun.size()>=limit){
            return JsonResult.success(listRun);
        }
        if (listRun.size()>0){
            limit=limit-listRun.size();
        }
        List listAdd = new ArrayList();
        listAdd.addAll(listRun);
        //待执行的任务
        List listPre =  taskMapper.getPreList(tenant.getId(),limit);
        listAdd.addAll(listPre);
        if (listPre.size()>=limit){
            return JsonResult.success(listAdd);
        }
        if (listPre.size()>0){
            limit = limit-listPre.size();
        }
        //已完成的任务
        List list =  taskMapper.getList(tenant.getId(),limit);
        if (list.size()>=limit){
            listAdd.addAll(list);
            return JsonResult.success(listAdd);
        }
        return JsonResult.success(listAdd);
    }

    /**
     * 查询任务统计
     * @param tenantCode
     * @return
     */
    @Override
    public JsonResult getCountList(String tenantCode) {
        Tenant tenant = tenantService.selectByTenantCode(tenantCode);
         List list =  taskMapper.getCountList(tenant.getId());;
        return JsonResult.success(list);
    }

    public Map getRunTaskByAirportId(int id){
        List<Map> list =  taskMapper.getRunTaskByAirportId(id);
        if (list.size()>0){
            return list.get(0);
        }
        return null;
    }
}
